ForeignKeyInfo constructor

const ForeignKeyInfo({
  1. required String referencedTable,
  2. required String referencedColumn,
  3. String? onDelete,
  4. String? onUpdate,
})

Foreign key information for DDL generation.

This is a simple data class that holds the information needed to generate foreign key constraints in DDL statements.

Implementation

const ForeignKeyInfo({
  required this.referencedTable,
  required this.referencedColumn,
  this.onDelete,
  this.onUpdate,
});