JoinsClause class

Renders a list of JOIN clauses.

Inheritance

Constructors

JoinsClause(List<Join<Schema, dynamic>> joins)
Creates a joins clause.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
joins List<Join<Schema, dynamic>>
The joins to render.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(RenderContext context) String
Renders this clause to SQL text, recording any bind values on context.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited