ColumnType<V extends Object?> extension type

A typed handle to a registered Column, as returned by the schema builder's column registration methods.

on
Implemented types
Available extensions

Constructors

ColumnType(Column<dynamic, V> _)

Properties

autoIncrement bool
Whether this column auto-increments (for primary keys).
getter/setter pairinherited
defaultValue ColumnOr<V>?
The column's default: a value in the column's own type, or an expression the database evaluates.
finalinherited
foreignKeyReference ForeignKeyReference?
Foreign key reference for this column.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isNullable bool
If the column is nullable;
finalinherited
isPrimaryKey bool
If the column is a primary key.
getter/setter pairinherited
name String
The name of the column.
finalinherited
nullable Column<dynamic, V?>
Returns the nullable version of this column.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqlType String?
The SQL type name (e.g., 'INTEGER', 'TEXT', 'TIMESTAMP').
finalinherited
table Table<Schema, dynamic>
The table of the column.
finalinherited
toJS JSPromise<T>

Available on Future<T>, provided by the FutureOfJSAnyToJSPromise extension

A JSPromise that either resolves with the result of the completed Future or rejects with an object that contains its error.
no setter
toJS JSPromise<JSAny?>

Available on Future<void>, provided by the FutureOfVoidToJSPromise extension

A JSPromise that either resolves once this Future completes or rejects with an object that contains its error.
no setter
transformer ColumnTransformer<V, Object?>?
A column's transformer for Dart to SQL conversion.
finalinherited

Methods

as(String alias) ColumnAlias<dynamic, V>

Available on ColumnOf<V>?, provided by the ColumnOperators extension

Make an alias of the column.
as(String alias) ColumnAlias<dynamic, V>
Make an alias of the column.
inherited
asStream() Stream<V>
Creates a Stream containing the result of this future.
inherited
between(ColumnOr<V> low, {required ColumnOr<V> and}) SQL

Available on ColumnOf<V>?, provided by the StringOperators extension

Row value of column is within the inclusive low to and range, lexicographically.
between(ColumnOr<V> low, {required ColumnOr<V> and}) SQL

Available on ColumnOf<V>?, provided by the IntOperators extension

Row value of column is within the inclusive low to and range.
catchError(Function onError, {bool test(Object error)?}) Future<V>
Handles errors emitted by this Future.
inherited
count() Count<V>

Available on ColumnOf<V>?, provided by the ColumnOperators extension

Returns the count of what is being selected.
decode(Object? input) → V?
A stored value back in this operand's own type.
inherited
encode(V? input) Object?
This operand's value in its stored form.
inherited
equals(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the ColumnOperators extension

Row value for column equals value.
greaterThan(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the StringOperators extension

Lexicographic ordering.
greaterThan(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the IntOperators extension

Row value of column is greater than value.
greaterThanOrEqual(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the StringOperators extension

Lexicographic ordering.
greaterThanOrEqual(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the IntOperators extension

Row value of column is greater than or equal value.
ignore() → void

Available on Future<T>, provided by the FutureExtensions extension

Completely ignores this future and its result.
inList(List<ColumnOr<V>> values) SQL

Available on ColumnOf<V>?, provided by the ColumnOperators extension

Row value for column is in the list of values.
inQuery(ToQuery<dynamic, V> query) SQL

Available on ColumnOf<V>?, provided by the ColumnOperators extension

Row value for column is in the rows query returns.
isFalse() SQL

Available on ColumnOf<V>?, provided by the BoolOperators extension

Row value of column is false.
isNotNull() SQL

Available on ColumnOf<V>?, provided by the ColumnOperators extension

Row value for column is not null.
isNull() SQL

Available on ColumnOf<V>?, provided by the ColumnOperators extension

Row value for column is null.
isTrue() SQL

Available on ColumnOf<V>?, provided by the BoolOperators extension

Row value of column is true.
lessThan(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the StringOperators extension

Lexicographic ordering.
lessThan(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the IntOperators extension

Row value of column is less than value.
lessThanOrEqual(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the IntOperators extension

Row value of column is less than or equal value.
lessThanOrEqual(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the StringOperators extension

Lexicographic ordering.
like(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the StringOperators extension

String like value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the ColumnOperators extension

Row value for column does not equal value. Binds like equals.
onError<E extends Object>(FutureOr<T> handleError(E error, StackTrace stackTrace), {bool test(E error)?}) Future<T>

Available on Future<T>, provided by the FutureExtensions extension

Handles errors on this future.
operand(ColumnOr<V> value) Object?

Available on ColumnOf<V>?, provided by the ColumnOperators extension

Prepares a predicate operand.
primaryKey() → T?

Available on T?, provided by the PrimaryColumn extension

Marks this column as the primary key (no auto-increment).
primaryKey({required bool autoIncrement}) → T

Available on T, provided by the PrimaryColumnInteger extension

Marks this integer column as the primary key, optionally with auto-increment.
primaryKey() → T

Available on T, provided by the PrimaryColumnNonNull extension

Marks this column as the primary key (no auto-increment).
references(ColumnOf<Object?>? columnGetter(), {ReferentialAction? onDelete, ReferentialAction? onUpdate}) → T

Available on T?, provided by the ReferencesColumn extension

Adds a foreign key reference to another column.
then<R>(FutureOr<R> onValue(V value), {Function? onError}) Future<R>
Register callbacks to be called when this future completes.
inherited
timeout(Duration timeLimit, {FutureOr<V> onTimeout()?}) Future<V>
Stop waiting for this future after timeLimit has passed.
inherited
to(ColumnOr<V> value) UpdateableColumn<V>

Available on ColumnOf<V>?, provided by the UpdateColumn extension

Set the column to value: a literal, another column, or an expression.
toString() String
A string representation of this object.
inherited
whenComplete(FutureOr<void> action()) Future<V>
Registers a function to be called when this future completes.
inherited

Operators

operator %(ColumnOr<V> value) Arithmetic<V>

Available on ColumnOf<V>?, provided by the ModuloOperator extension

this % value
operator *(ColumnOr<V> value) Arithmetic<V>

Available on ColumnOf<V>?, provided by the ArithmeticOperators extension

this * value
operator +(ColumnOr<V> value) Arithmetic<V>

Available on ColumnOf<V>?, provided by the ArithmeticOperators extension

this + value
operator -(ColumnOr<V> value) Arithmetic<V>

Available on ColumnOf<V>?, provided by the ArithmeticOperators extension

this - value
operator /(ColumnOr<V> value) Arithmetic<V>

Available on ColumnOf<V>?, provided by the ArithmeticOperators extension

this / value
operator <(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the IntOperators extension

Row value of column is less than value.
operator <=(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the IntOperators extension

Row value of column is less than or equal value.
operator ==(Object other) bool
The equality operator.
inherited
operator >(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the IntOperators extension

Row value of column is greater than value.
operator >=(ColumnOr<V> value) SQL

Available on ColumnOf<V>?, provided by the IntOperators extension

Row value of column is greater than or equal value.