InsertValuesBuilder<S extends Schema<R> , R, V> class
The insert builder that takes a list of values.
- Inheritance
-
- Object
- QueryBuilder<
S, V> - InsertBuilder<
S, R, V> - InsertValuesBuilder
Constructors
-
InsertValuesBuilder(RaindropExecutor<
Delegate> executor, {required QueryConfig config}) - The insert builder that takes a list of values.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
values(
List< R> values) → InsertWithValuesBuilder<S, R, V> -
Add the
valuesto the builder.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited