IntOperators<V extends int?> extension
Comparison operators for integer columns.
- on
-
- ColumnOf<
V> ?
- ColumnOf<
Methods
-
between(
ColumnOr< V> low, {required ColumnOr<V> and}) → SQL -
Available on ColumnOf<
Row value of column is within the inclusiveV> ?, provided by the IntOperators extensionlowtoandrange. -
greaterThan(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is greater thanV> ?, provided by the IntOperators extensionvalue. -
greaterThanOrEqual(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is greater than or equalV> ?, provided by the IntOperators extensionvalue. -
lessThan(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is less thanV> ?, provided by the IntOperators extensionvalue. -
lessThanOrEqual(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is less than or equalV> ?, provided by the IntOperators extensionvalue.
Operators
-
operator <(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is less thanV> ?, provided by the IntOperators extensionvalue. -
operator <=(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is less than or equalV> ?, provided by the IntOperators extensionvalue. -
operator >(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is greater thanV> ?, provided by the IntOperators extensionvalue. -
operator >=(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is greater than or equalV> ?, provided by the IntOperators extensionvalue.