Join<S extends Schema<R>, R> class abstract

Abstract class for defining joins.

Implementers

Constructors

Join(Table<S, R> table, {required Filter on})
Abstract class for defining joins.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
on Filter
The filter used for defining what to join on.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table Table<S, R>
The table to join.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited