LogicalFilter class

Provide logical filtering of AND/OR operations.

Inheritance
Available extensions

Constructors

LogicalFilter(Filter left, Filter right, {bool or = false})
Provide logical filtering of AND/OR operations.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
left Filter
The left filter.
final
or bool
If true it uses OR operations, otherwise AND operations.
final
The right filter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator &(Filter? right) Filter
Provide logical filtering of the AND operation.
inherited
operator &(Filter? right) Filter?

Available on F, provided by the FilterX extension

Provide logical filtering of the AND operation, returning right unchanged when this filter is null.
operator ==(Object other) bool
The equality operator.
inherited
operator |(Filter? right) Filter
Provide logical filtering of the OR operation.
inherited
operator |(Filter? right) Filter?

Available on F, provided by the FilterX extension

Provide logical filtering of the OR operation, returning right unchanged when this filter is null.