Migration class

A single migration unit containing a tag and SQL content.

Constructors

Migration(String tag, String sql)
A single migration unit containing a tag and SQL content.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sql String
The full SQL content to execute.
final
tag String
The migration identifier, e.g. "0000_initial".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited