NoopLogger class
A Logger implementation that has empty implementation for logging.
- Implemented types
Constructors
- NoopLogger()
-
A Logger implementation that has empty implementation for logging.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String query, List< Object?> values) → void -
Log a query statement and it's
values.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited