Raw<V extends Object?> class

A verbatim fragment of SQL.

Inheritance
Implemented types
Available extensions

Constructors

Raw(String sql)
A verbatim fragment of SQL.
Raw.parts(List<Object?> parts)
A verbatim fragment of SQL.

Properties

chunks List<Object?>
The fragment's pieces, in SQL chunk form.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSPromise<T>

Available on Future<T>, provided by the FutureOfJSAnyToJSPromise extension

A JSPromise that either resolves with the result of the completed Future or rejects with an object that contains its error.
no setter
toJS JSPromise<JSAny?>

Available on Future<void>, provided by the FutureOfVoidToJSPromise extension

A JSPromise that either resolves once this Future completes or rejects with an object that contains its error.
no setter
transformer ColumnTransformer<V, Object?>?
How this operand's values convert to and from their stored form.
no setterinherited

Methods

as(String alias) AliasedExpression<V>
Give this expression an output name, as Column.as does for a column.
inherited
asStream() Stream<V>
Creates a Stream containing the result of this future.
inherited
between(ColumnOr<V> low, {required ColumnOr<V> and}) SQL

Available on Expression<V>, provided by the NumericExpressionOperators extension

Value of this expression is within the inclusive low to and range.
between(ColumnOr<V> low, {required ColumnOr<V> and}) SQL

Available on Expression<V>, provided by the StringExpressionOperators extension

Value of this expression is within the inclusive low to and range, lexicographically.
build() SQL
Build the underlying SQL for this expression.
override
catchError(Function onError, {bool test(Object error)?}) Future<V>
Handles errors emitted by this Future.
inherited
decode(Object? input) → V?
A stored value back in this operand's own type.
inherited
encode(V? input) Object?
This operand's value in its stored form.
inherited
equals(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the ExpressionOperators extension

Value of this expression equals value.
greaterThan(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the NumericExpressionOperators extension

Value of this expression is greater than value.
greaterThan(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the StringExpressionOperators extension

Lexicographic ordering.
greaterThanOrEqual(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the NumericExpressionOperators extension

Value of this expression is greater than or equal to value.
greaterThanOrEqual(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the StringExpressionOperators extension

Lexicographic ordering.
ignore() → void

Available on Future<T>, provided by the FutureExtensions extension

Completely ignores this future and its result.
inList(List<ColumnOr<V>> values) SQL

Available on Expression<V>, provided by the ExpressionOperators extension

Value of this expression is in values.
inQuery(ToQuery<dynamic, V> query) SQL

Available on Expression<V>, provided by the ExpressionOperators extension

Value of this expression is among the rows query returns.
isNotNull() SQL

Available on Expression<V>, provided by the ExpressionOperators extension

Value of this expression is not null.
isNull() SQL

Available on Expression<V>, provided by the ExpressionOperators extension

Value of this expression is null.
lessThan(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the NumericExpressionOperators extension

Value of this expression is less than value.
lessThan(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the StringExpressionOperators extension

Lexicographic ordering.
lessThanOrEqual(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the NumericExpressionOperators extension

Value of this expression is less than or equal to value.
lessThanOrEqual(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the StringExpressionOperators extension

Lexicographic ordering.
like(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the StringExpressionOperators extension

Value of this expression matches the value pattern.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(ColumnOr<V> value) SQL

Available on Expression<V>, provided by the ExpressionOperators extension

Value of this expression does not equal value.
onError<E extends Object>(FutureOr<T> handleError(E error, StackTrace stackTrace), {bool test(E error)?}) Future<T>

Available on Future<T>, provided by the FutureExtensions extension

Handles errors on this future.
operand(ColumnOr<V> value) Object?

Available on Expression<V>, provided by the ExpressionOperators extension

then<R>(FutureOr<R> onValue(V value), {Function? onError}) Future<R>
Register callbacks to be called when this future completes.
inherited
timeout(Duration timeLimit, {FutureOr<V> onTimeout()?}) Future<V>
Stop waiting for this future after timeLimit has passed.
inherited
toString() String
A string representation of this object.
inherited
whenComplete(FutureOr<void> action()) Future<V>
Registers a function to be called when this future completes.
inherited

Operators

operator &(Filter? right) Filter
Provide logical filtering of the AND operation.
override
operator &(Filter? right) Filter?

Available on F, provided by the FilterX extension

Provide logical filtering of the AND operation, returning right unchanged when this filter is null.
operator ==(Object other) bool
The equality operator.
inherited
operator |(Filter? right) Filter
Provide logical filtering of the OR operation.
override
operator |(Filter? right) Filter?

Available on F, provided by the FilterX extension

Provide logical filtering of the OR operation, returning right unchanged when this filter is null.