singleOrNull property

Future<V?> get singleOrNull

The single element of this iterator, or null.

If the iterator has precisely one element, this is that element. Otherwise, if the iterator has zero elements, or it has two or more, the value is null.

Implementation

Future<V?> get singleOrNull async => (await this).singleOrNull;