Avg class
SQL AVG(value).
Always produces a floating point number, whatever went in, averaging integers gives a fraction.
- Inheritance
-
- Object
- Expression<
double> - Avg
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transformer
→ ColumnTransformer<
double, Object?> ? -
How this operand's values convert to and from their stored form.
no setterinherited
-
value
→ ColumnOr<
num?> -
The column or expression being averaged.
final
Methods
-
as(
String alias) → AliasedExpression< double> -
Give this expression an output name, as
Column.asdoes for a column.inherited -
asStream(
) → Stream< double> -
Creates a Stream containing the result of this future.
inherited
-
build(
) → SQL -
Build the underlying SQL for this expression.
override
-
catchError(
Function onError, {bool test(Object error)?}) → Future< double> -
Handles errors emitted by this Future.
inherited
-
decode(
Object? input) → double? -
A stored value back in this operand's own type.
override
-
encode(
double? input) → Object? -
This operand's value in its stored form.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
then<
R> (FutureOr< R> onValue(double value), {Function? onError}) → Future<R> -
Register callbacks to be called when this future completes.
inherited
-
timeout(
Duration timeLimit, {FutureOr< double> onTimeout()?}) → Future<double> -
Stop waiting for this future after
timeLimithas passed.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
whenComplete(
FutureOr< void> action()) → Future<double> -
Registers a function to be called when this future completes.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited