ColumnType<V extends Object?>
extension type
A typed handle to a registered Column, as returned by the schema builder's column registration methods.
Constructors
-
ColumnType(Column<
dynamic, V> _)
Properties
- autoIncrement ↔ bool
-
Whether this column auto-increments (for primary keys).
getter/setter pairinherited
-
defaultValue
→ ColumnOr<
V> ? -
The column's default: a value in the column's own type, or an
expression the database evaluates.
finalinherited
- foreignKeyReference ↔ ForeignKeyReference?
-
Foreign key reference for this column.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNullable → bool
-
If the column is nullable;
finalinherited
- isPrimaryKey ↔ bool
-
If the column is a primary key.
getter/setter pairinherited
- name → String
-
The name of the column.
finalinherited
-
nullable
→ Column<
dynamic, V?> -
Returns the nullable version of this column.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sqlType → String?
-
The SQL type name (e.g., 'INTEGER', 'TEXT', 'TIMESTAMP').
finalinherited
-
table
→ Table<
Schema, dynamic> -
The table of the column.
finalinherited
-
toJS
→ JSPromise<
T> -
Available on Future<
A JSPromise that either resolves with the result of the completed Future or rejects with an object that contains its error.T> , provided by the FutureOfJSAnyToJSPromise extensionno setter -
toJS
→ JSPromise<
JSAny?> -
Available on Future<
A JSPromise that either resolves once this Future completes or rejects with an object that contains its error.void> , provided by the FutureOfVoidToJSPromise extensionno setter -
transformer
→ ColumnTransformer<
V, Object?> ? -
A column's transformer for Dart to SQL conversion.
finalinherited
Methods
-
as(
String alias) → ColumnAlias< dynamic, V> -
Available on ColumnOf<
Make an alias of the column.V> ?, provided by the ColumnOperators extension -
as(
String alias) → ColumnAlias< dynamic, V> -
Make an alias of the column.
inherited
-
asStream(
) → Stream< V> -
Creates a Stream containing the result of this future.
inherited
-
between(
ColumnOr< V> low, {required ColumnOr<V> and}) → SQL -
Available on ColumnOf<
Row value of column is within the inclusiveV> ?, provided by the StringOperators extensionlowtoandrange, lexicographically. -
between(
ColumnOr< V> low, {required ColumnOr<V> and}) → SQL -
Available on ColumnOf<
Row value of column is within the inclusiveV> ?, provided by the IntOperators extensionlowtoandrange. -
catchError(
Function onError, {bool test(Object error)?}) → Future< V> -
Handles errors emitted by this Future.
inherited
-
count(
) → Count< V> -
Available on ColumnOf<
Returns the count of what is being selected.V> ?, provided by the ColumnOperators extension -
decode(
Object? input) → V? -
A stored value back in this operand's own type.
inherited
-
encode(
V? input) → Object? -
This operand's value in its stored form.
inherited
-
equals(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value for column equalsV> ?, provided by the ColumnOperators extensionvalue. -
greaterThan(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Lexicographic ordering.V> ?, provided by the StringOperators extension -
greaterThan(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is greater thanV> ?, provided by the IntOperators extensionvalue. -
greaterThanOrEqual(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Lexicographic ordering.V> ?, provided by the StringOperators extension -
greaterThanOrEqual(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is greater than or equalV> ?, provided by the IntOperators extensionvalue. -
ignore(
) → void -
Available on Future<
Completely ignores this future and its result.T> , provided by the FutureExtensions extension -
inList(
List< ColumnOr< values) → SQLV> > -
Available on ColumnOf<
Row value for column is in the list ofV> ?, provided by the ColumnOperators extensionvalues. -
inQuery(
ToQuery< dynamic, V> query) → SQL -
Available on ColumnOf<
Row value for column is in the rowsV> ?, provided by the ColumnOperators extensionqueryreturns. -
isFalse(
) → SQL -
Available on ColumnOf<
Row value of column is false.V> ?, provided by the BoolOperators extension -
isNotNull(
) → SQL -
Available on ColumnOf<
Row value for column is not null.V> ?, provided by the ColumnOperators extension -
isNull(
) → SQL -
Available on ColumnOf<
Row value for column is null.V> ?, provided by the ColumnOperators extension -
isTrue(
) → SQL -
Available on ColumnOf<
Row value of column is true.V> ?, provided by the BoolOperators extension -
lessThan(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Lexicographic ordering.V> ?, provided by the StringOperators extension -
lessThan(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is less thanV> ?, provided by the IntOperators extensionvalue. -
lessThanOrEqual(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is less than or equalV> ?, provided by the IntOperators extensionvalue. -
lessThanOrEqual(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Lexicographic ordering.V> ?, provided by the StringOperators extension -
like(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
String likeV> ?, provided by the StringOperators extensionvalue. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notEquals(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value for column does not equalV> ?, provided by the ColumnOperators extensionvalue. Binds like equals. -
onError<
E extends Object> (FutureOr< T> handleError(E error, StackTrace stackTrace), {bool test(E error)?}) → Future<T> -
Available on Future<
Handles errors on this future.T> , provided by the FutureExtensions extension -
operand(
ColumnOr< V> value) → Object? -
Available on ColumnOf<
Prepares a predicate operand.V> ?, provided by the ColumnOperators extension -
primaryKey(
) → T? -
Available on T?, provided by the PrimaryColumn extension
Marks this column as the primary key (no auto-increment). -
primaryKey(
{required bool autoIncrement}) → T -
Available on T, provided by the PrimaryColumnInteger extension
Marks this integer column as the primary key, optionally with auto-increment. -
primaryKey(
) → T -
Available on T, provided by the PrimaryColumnNonNull extension
Marks this column as the primary key (no auto-increment). -
references(
ColumnOf< Object?> ? columnGetter(), {ReferentialAction? onDelete, ReferentialAction? onUpdate}) → T -
Available on T?, provided by the ReferencesColumn extension
Adds a foreign key reference to another column. -
then<
R> (FutureOr< R> onValue(V value), {Function? onError}) → Future<R> -
Register callbacks to be called when this future completes.
inherited
-
timeout(
Duration timeLimit, {FutureOr< V> onTimeout()?}) → Future<V> -
Stop waiting for this future after
timeLimithas passed.inherited -
to(
ColumnOr< V> value) → UpdateableColumn<V> -
Available on ColumnOf<
Set the column toV> ?, provided by the UpdateColumn extensionvalue: a literal, another column, or an expression. -
toString(
) → String -
A string representation of this object.
inherited
-
whenComplete(
FutureOr< void> action()) → Future<V> -
Registers a function to be called when this future completes.
inherited
Operators
-
operator %(
ColumnOr< V> value) → Arithmetic<V> -
Available on ColumnOf<
V> ?, provided by the ModuloOperator extensionthis % value -
operator *(
ColumnOr< V> value) → Arithmetic<V> -
Available on ColumnOf<
V> ?, provided by the ArithmeticOperators extensionthis * value -
operator +(
ColumnOr< V> value) → Arithmetic<V> -
Available on ColumnOf<
V> ?, provided by the ArithmeticOperators extensionthis + value -
operator -(
ColumnOr< V> value) → Arithmetic<V> -
Available on ColumnOf<
V> ?, provided by the ArithmeticOperators extensionthis - value -
operator /(
ColumnOr< V> value) → Arithmetic<V> -
Available on ColumnOf<
V> ?, provided by the ArithmeticOperators extensionthis / value -
operator <(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is less thanV> ?, provided by the IntOperators extensionvalue. -
operator <=(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is less than or equalV> ?, provided by the IntOperators extensionvalue. -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is greater thanV> ?, provided by the IntOperators extensionvalue. -
operator >=(
ColumnOr< V> value) → SQL -
Available on ColumnOf<
Row value of column is greater than or equalV> ?, provided by the IntOperators extensionvalue.