DeleteLimitedBuilder<S extends Schema<R> , R, V> class
A delete whose row cap is set: still awaitable and decoratable, no longer filterable.
- Inheritance
-
- Object
- QueryBuilder<
S, V> - DeleteBuilder<
S, R, V> - DeleteLimitedBuilder
- Mixed-in types
-
- ToQuery<
S, V>
- ToQuery<
Constructors
-
DeleteLimitedBuilder(RaindropExecutor<
Delegate> executor, {required QueryConfig config}) - A delete whose row cap is set: still awaitable and decoratable, no longer filterable.
Properties
-
first
→ Future<
V> -
The first element.
no setterinherited
-
firstOrNull
→ Future<
V?> -
The first element of this iterator, or
nullif the iterable is empty.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
last
→ Future<
V> -
The last element.
no setterinherited
-
lastOrNull
→ Future<
V?> -
The last element of this iterable, or
nullif the iterable is empty.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
single
→ Future<
V> -
Checks that this iterable has only one element, and returns that element.
no setterinherited
-
singleOrNull
→ Future<
V?> -
The single element of this iterator, or
null.no setterinherited
Methods
-
asStream(
) → Stream< List< V> > -
Creates a Stream containing the result of this future.
inherited
-
catchError(
Function onError, {bool test(Object error)?}) → Future< List< V> > -
Handles errors emitted by this Future.
inherited
-
compile(
{bool qualified = false}) → Query< V> -
Compiles this builder's config into a renderable + decodable statement.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
then<
R> (FutureOr< R> onValue(List<V> value), {Function? onError}) → Future<R> -
Register callbacks to be called when this future completes.
inherited
-
timeout(
Duration timeLimit, {FutureOr< List< onTimeout()?}) → Future<V> >List< V> > -
Stop waiting for this future after
timeLimithas passed.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
whenComplete(
FutureOr< void> action()) → Future<List< V> > -
Registers a function to be called when this future completes.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited