Derived5<V0, V1, V2, V3, V4> class
Constructors
-
Derived5(SchemaBuilder<
(V0, V1, V2, V3, V4)> $, ColumnType<V0> $1, ColumnType<V1> $2, ColumnType<V2> $3, ColumnType<V3> $4, ColumnType<V4> $5)
Properties
-
$
→ Table<
Schema< (V0, V1, V2, V3, V4)> , (V0, V1, V2, V3, V4)> -
The Table backing this schema reference.
finalinherited
-
$1
→ ColumnType<
V0> -
final
-
$2
→ ColumnType<
V1> -
final
-
$3
→ ColumnType<
V2> -
final
-
$4
→ ColumnType<
V3> -
final
-
$5
→ ColumnType<
V4> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromRow(
RowReader read) → (V0, V1, V2, V3, V4) -
Construct a row instance from a typed
readfunction.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited