MigrationChecksumMismatch class
Thrown when a previously applied migration's checksum doesn't match the current source, indicating schema drift.
- Implemented types
Constructors
- MigrationChecksumMismatch(String tag, String expected, String actual)
-
Creates a new MigrationChecksumMismatch.
const
Properties
- actual → String
-
The current checksum of the migration source.
final
- expected → String
-
The checksum that was recorded when the migration was applied.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
The migration tag that has a checksum mismatch.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited