ToQuery<S, V> mixin
Makes a terminal builder awaitable.
- Superclass constraints
- QueryBuilder<
S, V>
- QueryBuilder<
- Implemented types
- Mixin applications
- Available extensions
Properties
-
first
→ Future<
V> -
The first element.
no setter
-
firstOrNull
→ Future<
V?> -
The first element of this iterator, or
nullif the iterable is empty.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
last
→ Future<
V> -
The last element.
no setter
-
lastOrNull
→ Future<
V?> -
The last element of this iterable, or
nullif the iterable is empty.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
single
→ Future<
V> -
Checks that this iterable has only one element, and returns that element.
no setter
-
singleOrNull
→ Future<
V?> -
The single element of this iterator, or
null.no setter
Methods
-
asStream(
) → Stream< List< V> > -
Creates a Stream containing the result of this future.
override
-
catchError(
Function onError, {bool test(Object error)?}) → Future< List< V> > -
Handles errors emitted by this Future.
override
-
compile(
{bool qualified = false}) → Query< V> - Compiles this builder's config into a renderable + decodable statement.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
then<
R> (FutureOr< R> onValue(List<V> value), {Function? onError}) → Future<R> -
Register callbacks to be called when this future completes.
override
-
timeout(
Duration timeLimit, {FutureOr< List< onTimeout()?}) → Future<V> >List< V> > -
Stop waiting for this future after
timeLimithas passed.override -
toString(
) → String -
A string representation of this object.
inherited
-
whenComplete(
FutureOr< void> action()) → Future<List< V> > -
Registers a function to be called when this future completes.
override
-
withClause<
B extends QueryBuilder> (int weight, Clause build(QueryConfig config), B create(RaindropExecutor< Delegate> executor, {required QueryConfig config})) → B -
Available on QueryBuilder<
Returns this builder copied viaS, V> , provided by the Extras extensioncreate, with the clause built bybuildplaced atweight.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited