IndexSnapshot class
Represents an index snapshot.
- Annotations
-
- @immutable
Constructors
Properties
-
columns
→ List<
String> -
The column names that make up the index.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isUnique → bool
-
Whether this index enforces uniqueness.
final
- name → String
-
The index name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableName → String
-
The table this index belongs to.
final
- where → String?
-
Optional partial-index predicate (raw SQL).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toIndexInfo(
) → IndexInfo - Converts the index snapshot to the IndexInfo the DDL generators consume.
-
toMap(
) → Map< String, dynamic> - Converts the index snapshot to a map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override